Learn R Programming

EstimateBreed (version 1.0.2)

atsum: Accumulated Thermal Sum

Description

Calculates the daily and accumulated thermal sum, considering the subtraction of the average air temperature by the lower cardinal temperature for each crop.

Usage

atsum(AAT, crop = "maize", lbt = NULL, verbose = FALSE, plot = FALSE)

Value

Returns the cumulative and total thermal sum considering the cultivation cycle of the selected crop. Also presents the following parameters:


* Total Cycle

The number of cycle days, for verification.


* TS

The value of the total thermal sum, in daily degree days (GDD).


* TBi

The value used for the lower base temperature.


* General Parameters

Considering the reported average air temperature values, it returns the maximum, minimum, and coefficient of variation.

Arguments

AAT

The column with the average air temperature values.

crop

Parameter to define the culture. Use 'maize' for maize, 'soybean' for soybean, 'flax' for flaxseed, 'trit' for wheat or 'oat' for oat crop.

lbt

Parameter to define the value of the lower basal temperature to be used in the calculation. If not informed, the function will use the values of 10, 5, 2, 2 and 0 \(^{\circ}C\) for maize, soybeans, flaxseed, wheat and oats, respectively.

verbose

Logical argument. Runs the code silently if FALSE.

plot

Logical argument. Plot a graph of thermal accumulation if TRUE.

Author

Willyan Junior Adorian Bandeira

Ivan Ricardo Carvalho

Murilo Vieira Loro

Leonardo Cesar Pradebon

Jose Antonio Gonzalez da Silva

Examples

Run this code
library(EstimateBreed)

data("clima")
clima <- get("clima")[1:150, ]

with(clima,atsum(TMED,crop="maize"))

#Adjusting lower basal temperature manually
with(clima,atsum(TMED,crop="maize",lbt=12))

Run the code above in your browser using DataLab