desv_clim: Auxiliary function for calculating ISGR
Description
This function receives a dataframe with temperature and precipitation data
and calculates the standard deviation of these parameters for each environment.
Usage
desv_clim(ENV, AAT, PREC)
Value
A dataframe containing the identifier of the selection environment and
the standard deviations for temperature and precipitation.
Arguments
ENV
Identification of each selection environment (to differentiate if
there is more than one cultivation cycle).
AAT
Average air temperature (in degree Celsius) during the cycle in
each environment.
PREC
Rainfall (in mm) during the cultivation cycle in each environment
library(EstimateBreed)
data("desvamb")
head(desvamb)
#Use DPclim for the ISGR function to identify deviations correctlyDPclim <- with(desvamb,desv_clim(ENV,TMED,PREC))